/*
 * Copyright (C) 2003 Andrej Bagon <andrej.bagon@uni-mb.si>
 *
 * This file is part of media-box, a free multimedia system.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 */

#include <stdlib.h>
#include <stdio.h>
#include <sys/ioctl.h>
#include <sys/mount.h>
#include <linux/cdrom.h>
#include <fcntl.h>
#include <unistd.h>
#include <string.h>

#include <gtk/gtk.h>

#include "automount.h"

gint is_dvd(const gchar *device, const gchar *filename)
{
  gint fd;
  gint ret;
  gchar dvd[4096];

  ret = 0;
  if (mount(device, filename, "iso9660", MS_RDONLY, NULL) == -1)
    {// error mounting!
#ifdef _DEBUG_
      printf("error mounting..maybe already mounted..\n");
#endif
    }
  
  sprintf(dvd,"%s/video_ts/",filename);
  fd = open(dvd, O_RDONLY);
  if (fd != -1)
    {
      // sucessful open,
      // this means that I probbably have a DVD
      ret = 1;
      close(fd);
      umountdrive(filename);
    }
  else
    {
#ifdef _DEBUG_
       printf("no dvd...\n");
#endif
      umountdrive(filename);
    }
  
  return ret;
} 

gint is_vcd(const gchar *device, const gchar *filename)
{
  gint fd;
  gint ret;
  gchar dvd[4096];

  ret = 0;
  if (mount(device, filename, "iso9660", MS_RDONLY, NULL) == -1)
    {// error mounting!
#ifdef _DEBUG_
      printf("error mounting..maybe already mounted..\n");
#endif
    }
  
  sprintf(dvd,"%s/vcd/",filename);
  fd = open(dvd, O_RDONLY);
  if (fd != -1)
    {
      // sucessful open,
      // this means that I probbably have a VCD
      close(fd);
       
      // another check for a VCD
      sprintf(dvd,"%s/cdi/",filename);
      fd = open(dvd, O_RDONLY);
      if (fd != -1)
	 {
	    // sucessful open,
	    // this means that I probbably have a VCD
	    ret = 1;
	    close(fd);
	 }
       umountdrive(filename);
    }
  else
    {
#ifdef _DEBUG_
       printf("no vcd...\n");
#endif
      umountdrive(filename);
    }
  
  return ret;
} 

void umountdrive(const gchar *filename)
{
  if (umount(filename) == -1)
    {
#ifdef _DEBUG_
      printf("error umounting device...\n");
#endif
    }
}

void mountdrive(const gchar *device, const gchar *filename)
{
   if (mount(device, filename, "iso9660", MS_RDONLY, NULL) == -1)
     {// error mounting!
#ifdef _DEBUG_
	printf("error mounting..maybe already mounted..\n");
#endif
     }
}

gint is_audio(const gchar *device)
{
   int fd;
   int status;
   
   fd = open(device, O_RDONLY | O_NONBLOCK);
   if (fd < 0)
     {
#ifdef _DEBUG_
	printf("error opening device...\n");
#endif
	return 0;
     }
   status = ioctl(fd, CDROM_DRIVE_STATUS, CDSL_CURRENT);
   
   if (status == CDS_DISC_OK)
     {
	status = ioctl(fd, CDROM_DISC_STATUS, CDSL_CURRENT);
	close(fd);
	if (status == CDS_AUDIO)
	  return 1;
     }
   
   return 0;
}

gint checkdrive(const gchar *device, const gchar *mountpoint)
{
   int fd;
   int status;
   int flag;
   
   flag = 0;
   
   // open the file
   fd = open(device, O_RDONLY | O_NONBLOCK);
   if (fd < 0)
     {
#ifdef _DEBUG_
	printf("Error opening %s\n",mountpoint);
#endif      
	return flag;
     }
   
   // read the drive status info
   status = ioctl(fd, CDROM_DRIVE_STATUS, CDSL_CURRENT);
   
#ifdef _DEBUG_
   printf("status->%d\n",status);
#endif
   switch (status)
     {
	// if there is an OK disc
      case CDS_DISC_OK:
#ifdef _DEBUG_
	printf("OK lets continue...\n");
#endif
	if (flag)
	  {
	     // release the device
	     close(fd);
	     break;
	  }
	flag = 1;
	// read the disc status info
	status = ioctl(fd, CDROM_DISC_STATUS, CDSL_CURRENT);
	// release the drive
	close(fd);
	switch (status)
	  {
	   case CDS_AUDIO:
	     // found audio cd..
#ifdef _DEBUG_
	     printf("audio cd...\n");
#endif
	     break;
	   case CDS_DATA_1:
	     // found a data cd
#ifdef _DEBUG_
	     printf("data cd...\n");
#endif
	     if (mount(device, mountpoint, "iso9660", MS_RDONLY, NULL) == -1)
	       {// error mounting!
#ifdef _DEBUG_
		  printf("error mounting..maybe already mounted..\n");
#endif
	       }
	     
	     break;
	   case CDS_MIXED:
	     // found a mixed data/audio cd
#ifdef _DEBUG_
	     printf("mixed data/audio cd...\n");
#endif
	     break;
	   default:
	     // cant determine disc type
#ifdef _DEBUG_
	     printf("can not determine cd type...\n");
#endif
	     break;
	  }
	break;
      case CDS_NO_INFO:
#ifdef _DEBUG_
	printf("You have a weird CDROM. It will never work with this program.\n");
#endif
	break;
      default:
	// release the drive
#ifdef _DEBUG_
	printf("No cd?\n");
#endif
	flag = 0;
	close(fd);
     }
   
   return flag;
}
