/*
 * Copyright (C) 2003 Andrej Bagon <andrej.bagon@uni-mb.si>
 *
 * This file is part of media-box, a free multimedia system.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 */

#include <stdlib.h>
#include <stdio.h>
#include <dirent.h>
#include <string.h>
#include <gtk/gtk.h>

#include <unistd.h>
#include <fcntl.h>
#include <termios.h>
#include <sys/types.h>
#include <sys/ioctl.h>      
#include <linux/cdrom.h>

#include "media-box.h"
#include "filename.h"

struct cdrom_tochdr tochdr;

gint test_is_directory(const gchar *directory)
{
   struct dirent **namelist;
   gint n;
   
   n = scandir(directory, &namelist, 0, alphasort);
	
   if (n < 0)
     {
	// it is a file ...
	return 0;
     }
   else
     {
	// it is a directory ...
	while(n--)
	  {
	     free(namelist[n]);
	  }
	free(namelist);
	return 1;
     }
   
   // if we are here something is wrong!
   return -1;
}

gint up_directory(gchar *directory)
{
   int i;

   i=strlen(directory)-1;
   for (;i>=0;i--)
     {
	if (directory[i] == '/')
	  {
	     directory[i]='\0';
	     break;
	  }
     }
   
   if (directory[0]=='\0')
     {
	directory[0]='/';
	directory[1]='\0';
     }
   
   return 0;
}

int swap_slashes(gchar *text)
{
   int i;
   
   for(i=0;i<strlen(text);i++)
     {
	if (text[i] == '\\')
	  text[i] = '/';	  
     }

   return 0;
}

gint seek_dir(const gchar *directory, gint type, struct files *file_list, gint *pos)
{
   struct dirent **namelist;
   gint n,i;
   gchar filename[NAME_MAX];
   gchar extension[NAME_MAX];

   if (type == PLAYLIST_FILE)
     {
	FILE *fil;
	char m3u_file[4092];
	int m3u_pos;
	
	m3u_pos = *pos;
	*pos = 0;
#ifdef _DEBUG_
	printf("work with playlist...\n");
#endif
	sprintf(file_list[*pos].filename,"Up one level");
	sprintf(file_list[*pos].pathfile,"%s",directory);
	file_list[*pos].type = DIRECTORY_TYPE;
	*pos = *pos+1;

	// read the playlist en load it in file_list
	sprintf(m3u_file,"%s/%s",directory, file_list[m3u_pos].filename);

	fil = fopen(m3u_file,"r");
	if (fil != NULL)
	  {
	     do
	       {
		  m3u_file[0]='\0';
		  read_line(fil, m3u_file);
		  if (m3u_file[0]!='\0')
		    { // if not empty string
		       swap_slashes(m3u_file);
		       sprintf(file_list[*pos].filename,"%s",m3u_file);
		       sprintf(file_list[*pos].pathfile,"%s/%s",directory,m3u_file);
		       file_list[*pos].type = MUSIC_TYPE;
		       *pos = *pos+1;
		    }
#ifdef _DEBUG_
		  printf("%s\n",m3u_file);
#endif
	       }
	     while (!feof(fil));
	     
	     fclose(fil);
	  }
	
	return 0;
     }
   
   n = scandir(directory, &namelist, 0, alphasort);
#ifdef _DEBUG_
   printf("seekdir: %s type: %d\n",directory,type);
#endif
   if (n < 0)
     {
#ifdef _DEBUG_
	printf("Error reading directory...\n");
#endif
     }
   else
     {
	sprintf(file_list[*pos].filename,"Up one level");
	sprintf(file_list[*pos].pathfile,"%s",directory);
	up_directory(file_list[*pos].pathfile);
	file_list[*pos].type = DIRECTORY_TYPE;
	*pos = *pos+1;
	
	for (i = 0; i < n ; i++)
	  {
	     gchar tmp[PATH_MAX+NAME_MAX];
	     
	     sprintf(tmp,"%s/%s",directory,namelist[i]->d_name);
	     if (test_is_directory(tmp))
	       {
		  if (namelist[i]->d_name[0] != '.')
		    if (strncmp(namelist[i]->d_name,"..",2))
		      {
			 sprintf(file_list[*pos].filename,"%s", namelist[i]->d_name);
			 sprintf(file_list[*pos].pathfile,"%s", tmp);
			 file_list[*pos].type = DIRECTORY_TYPE;
			 *pos = *pos+1;
		      }
	       }
	     else
	       {
		  sprintf(filename,"%s",namelist[i]->d_name);
		  if (rindex(filename, '.') != NULL ) 
		    strncpy(extension, rindex(filename, '.'), strlen(rindex(filename, '.')));
		  
		  if (type == MOVIE_TYPE)
		    {
		       if ((!strncasecmp(extension,".avi",4)) ||
			   (!strncasecmp(extension,".mpg",4)) ||
			   (!strncasecmp(extension,".mpeg",5)) ||
			   (!strncasecmp(extension,".mov",4)) ||
			   (!strncasecmp(extension,".wmv",4)) ||
			   (!strncasecmp(extension,".vob",4)) ||
			   (!strncasecmp(extension,".divx",5)) ||
			   (!strncasecmp(extension,".dat",4)) ||
			   (!strncasecmp(extension,".ram",4)))
			 
			 {
			    sprintf(file_list[*pos].filename,"%s",filename);
			    sprintf(file_list[*pos].pathfile,"%s/%s",directory,filename);
			    file_list[*pos].type = MOVIE_TYPE;
			    *pos = *pos+1;
			 }
		    }
		  
		  else if (type == SUB_TYPE)
		    {
		       if ((!strncasecmp(extension,".sub",4)) ||
			   (!strncasecmp(extension,".txt",4)) ||
			   (!strncasecmp(extension,".srt",4)) )
			 {
			    sprintf(file_list[*pos].filename,"%s",filename);
			    sprintf(file_list[*pos].pathfile,"%s/%s",directory,filename);
			    file_list[*pos].type = SUB_TYPE;
			    *pos = *pos+1;
			 }
		    }
		  else if (type == MUSIC_TYPE)
		    {
		       if (!strncasecmp(extension,".m3u",4))
			   { // to 
			      sprintf(file_list[*pos].filename,"%s",filename);
			      sprintf(file_list[*pos].pathfile,"%s",directory);
#ifdef _DEBUG_
			      printf("m3u playlist: %s\n",file_list[*pos].pathfile);
#endif
			      file_list[*pos].type = PLAYLIST_FILE;
			      *pos = *pos+1;
#ifdef _DEBUG_
			      printf("m3u playlist\n");
#endif
			   }
			   
		       if ((!strncasecmp(extension,".mp3",4)) ||
			   (!strncasecmp(extension,".wav",4)) ||
			   (!strncasecmp(extension,".ac3",4)) ||
			   (!strncasecmp(extension,".mp4",4)) ||
			   (!strncasecmp(extension,".aac",4)) ||
			   (!strncasecmp(extension,".ogg",4)))
			 {
			    sprintf(file_list[*pos].filename,"%s",filename);
			    sprintf(file_list[*pos].pathfile,"%s/%s",directory,filename);
			    file_list[*pos].type = MUSIC_TYPE;
			    *pos = *pos+1;
			 }
		    }
		  else if (type == PICTURE_TYPE)
		    {
		       if ((!strncasecmp(extension,".png",4)) ||
			   (!strncasecmp(extension,".jpeg",5)) ||
			   (!strncasecmp(extension,".jpg",4)) ||
			   (!strncasecmp(extension,".gif",4)) ||
			   (!strncasecmp(extension,".ico",4)) ||
			   (!strncasecmp(extension,".ras",4)) ||
			   (!strncasecmp(extension,".xpm",4)) ||
			   (!strncasecmp(extension,".tiff",5)) ||
			   (!strncasecmp(extension,".tif",4)) ||
			   (!strncasecmp(extension,".pnm",4)) ||
			   (!strncasecmp(extension,".bmp",4)) ||
			   (!strncasecmp(extension,".xbm",4)) )
			 {
			    sprintf(file_list[*pos].filename,"%s",filename);
			    sprintf(file_list[*pos].pathfile,"%s/%s",directory,filename);
			    file_list[*pos].type = 4;
			    *pos = *pos+1;
			 }
		    }
	       }
	     free(namelist[i]);
	  }
	
	free(namelist);
     }
   
   return 0;
}

gint seek_audio(const gchar *directory, struct files *file_list, gint *pos)
{
   int drive = 0;
   int first = 0;
   int last = 0;
   int i;
   
   drive = open(directory, O_RDONLY);
   if (drive)
     {
	ioctl(drive, CDROMREADTOCHDR, &tochdr);
	first = tochdr.cdth_trk0;   /* first track */
	last  = tochdr.cdth_trk1;   /* last track */
	close(drive);
     }
   
   *pos = 0;
   sprintf(file_list[*pos].filename,"Up one level");
   sprintf(file_list[*pos].pathfile,"/");
   file_list[*pos].type = DIRECTORY_TYPE;
   *pos = *pos+1;
   
   for (i = first;i<=last;i++)
     {
	sprintf(file_list[*pos].filename,"Track %d",i);
	sprintf(file_list[*pos].pathfile,"cdda:/%d",i);
	file_list[*pos].type = 6;
	*pos = *pos + 1;
	
     }
   
   return 0;
}
