/*
 * Copyright (C) 2003 Andrej Bagon <andrej.bagon@uni-mb.si>
 *
 * This file is part of media-box, a free multimedia system.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 */

#include <stdlib.h>
#include <stdio.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <glib.h>

#include "media-box.h"

/* invisible cursor */
#define cursor1_width 16
#define cursor1_height 16

static unsigned char cursor1_bits[] =
{
   0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0,
   0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0,
   0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0
};

gboolean on_window_delete_event (GtkWidget *widget,
				 GdkEvent  *event,
				 gpointer  user_data)
{
   gtk_main_quit();
   return FALSE;
}

gboolean load_pixbufs (GError **error)
{
//  gint i;
   gchar file[4092];
   
   if (background)
     return TRUE; /* already loaded earlier */
   
   sprintf(file,"%s/img/%s", DIRECTORY, main_info.back_image);
#ifdef _DEBUG_
   printf("==->: %s\n",file);
#endif
   background = gdk_pixbuf_new_from_file (file, error);
   
   if (!background)
     {
#ifdef _DEBUG_
	printf("Error loading background...\n");
#endif
	return FALSE; /* Note that "error" was filled with a GError */
     }
   
   back_width = gdk_pixbuf_get_width (background);
   back_height = gdk_pixbuf_get_height (background);
   
   sprintf(file,"%s/img/%s", DIRECTORY, buttons[0].base);
   error = NULL;
   images[0] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY, buttons[1].base);
   error = NULL;
   images[1] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY, buttons[2].base);
   error = NULL;
   images[2] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY, buttons[3].base);
   error = NULL;
   images[3] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY, main_info.title_image);
   error = NULL;
   images[7] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY, main_info.main_image);
   error = NULL;
   images[8] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/divx_back.png", DIRECTORY);//,divx_info.back);
   error = NULL;
   images[9] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY,divx_info.over);
   error = NULL;
#ifdef _DEBUG_
   printf("=->%s\n",file);
#endif
   images[10] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY,divx_info.play);
   error = NULL;
   images[11] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY,divx_info.title);
   error = NULL;
   images[12] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY, mp3_info.title);
   error = NULL;
   images[18] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY, image_info.title);
   error = NULL;
   images[19] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY, buttons[0].over);
   error = NULL;
   images[21] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY, buttons[1].over);
   error = NULL;
   images[22] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY, buttons[2].over);
   error = NULL;
   images[23] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY, buttons[3].over);
   error = NULL;
   images[24] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY, buttons[4].over);
   error = NULL;
   images[25] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/%s", DIRECTORY, buttons[5].over);
   error = NULL;
   images[26] = gdk_pixbuf_new_from_file (file, error);
   
   sprintf(file,"%s/img/file_selector.png", DIRECTORY);
   error = NULL;
   images[37] = gdk_pixbuf_new_from_file (file, error);
   
   return TRUE;
}

void put_picture(gint posx, gint posy, gint i, gint mode)
{
   GdkRectangle r1, r2, dest;
   gint width, height;
   
   width = gdk_pixbuf_get_width(images[i]);
   height = gdk_pixbuf_get_height(images[i]);
   
   r1.x = posx;
   r1.y = posy;
   r1.width = width;
   r1.height = height;
   
   r2.x = 0;
   r2.y = 0;
   r2.width = back_width;
   r2.height = back_height;
   
   if (gdk_rectangle_intersect (&r1, &r2, &dest))
     {
      gdk_pixbuf_composite (images[i],
			    frame,
			    posx,posy,
			    width, height,
			    posx, posy,
			    1, 1,
			    GDK_INTERP_NEAREST,
			    mode);
     }
}

GtkWidget *do_pixbufs (void)
{
   if (!window)
     {
	GError *error;
	
	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title (GTK_WINDOW (window), "mediabox");
	gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
	
	g_signal_connect (window, "destroy",
			  G_CALLBACK (gtk_widget_destroyed), &window);
	g_signal_connect (window, "key_press_event",
			  G_CALLBACK (on_window_key_press_event),
			  NULL);
	//       g_signal_connect (window, "lirc_event",
	//			 G_CALLBACK (on_lirc_event),
	//			 NULL);
	g_signal_connect (window, "delete_event",
			  G_CALLBACK (on_window_delete_event),
			  NULL);
	error = NULL;
	
	load_pixbufs (&error);

	// window should be of window width and height
//	gtk_widget_set_size_request (window, back_width, back_height);
	my_display = XOpenDisplay (NULL);
	my_screen = DefaultScreen (my_display);
//	gtk_widget_set_size_request (window, DisplayWidth(my_display, my_screen), DisplayHeight(my_display, my_screen));
	gtk_widget_set_size_request (window, back_width, back_height );
	
	frame = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, back_width, back_height);
	
	da = gtk_drawing_area_new ();
	
	gtk_container_add(GTK_CONTAINER(window), da);
	
     }
   
   if (!GTK_WIDGET_VISIBLE (window))
     {
	GdkCursor *cursor;
	GdkPixmap *source;
	GdkColor fg = { 0, 0, 0, 0 };
	
	gtk_widget_show_all (window);
	source = gdk_bitmap_create_from_data (NULL, cursor1_bits,
					      cursor1_width, cursor1_height);
	
	cursor = gdk_cursor_new_from_pixmap (source, source, &fg, &fg, 0, 0);
	gdk_window_set_cursor (window->window, cursor);
	
	gtk_window_move(GTK_WINDOW(window),0,0);
     }
   else
     {
	gtk_widget_destroy (window);
	window = NULL;
     }
   
   return window;
}
