/*
 * Copyright (C) 2003 Andrej Bagon <andrej.bagon@uni-mb.si>
 *
 * This file is part of media-box, a free multimedia system.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 */

#include "media-box.h"
#include <gtk/gtk.h>

void refresh_window(void)
{
   switch (meni)
     {
      case ROOT_MENI:
	main_meni(&menu_pos);
	break;
      case MOVIE_MENI:
	movie_meni(&menu_pos);
	break;
      case MUSIC_MENI:
	music_meni(&menu_pos);
	break;
      case PICTURE_MENI:
	picture_meni(&menu_pos);
	break;
      case SHOW_PICTURE:
	picture_meni(&menu_pos);
	break;
      case SUB_MENI:
	sub_meni(&menu_pos);
	break;
      case PLAY_MUSIC:
	play_music_refresh();
	break;
      default:
	break;
     }
}

void down_press(void)
{
   switch (meni)
     {	
      case PLAY_MOVIE:
	xine_movie_press(LIRC_DOWN);
	break;
      default:
	menu_pos++;
	refresh_window();
	break;
     }
}

void up_press(void)
{
   switch (meni)
     {
      case PLAY_MOVIE:
	xine_movie_press(LIRC_UP);
	break;
      default:
	menu_pos--;
	refresh_window();
	break;
     }
}

void right_press(void)
{
   switch (meni)
     {	
      case PLAY_MOVIE:
	xine_movie_press(LIRC_RIGHT);
	break;
      default:
	break;
     }   
}

void left_press(void)
{
   switch (meni)
     {
      case PLAY_MOVIE:
	xine_movie_press(LIRC_LEFT);
	break;
      default:
	break;
     }
}

void menu_press(void)
{
   switch (meni)
     {
      case PLAY_MOVIE:
	xine_movie_press(LIRC_MENU1);
	break;
      default:
	break;
     }
}

void select_press(void)
{
   switch (meni)
     {
      case ROOT_MENI:
	main_select(menu_pos);
	break;
      case MOVIE_MENI:
	movie_select(menu_pos);
	break;
      case MUSIC_MENI:
	music_select(menu_pos);
	break;
      case PICTURE_MENI:
	picture_select(menu_pos);
	break;
      case SUB_MENI:
	sub_select(menu_pos);
	break;
      case PLAY_MOVIE:
	xine_movie_press(LIRC_ENTER);
	break;
      default:
	break;
     }
#ifdef _DEBUG_
   printf("meni 0> %d\n",menu_pos);
   printf("cur_path: %s\n",cur_path);
#endif
   refresh_window();
}

void play_press(void)
{
   switch (meni)
     {
      case ROOT_MENI:
	main_select(menu_pos);
	break;
      case MOVIE_MENI:
	movie_play(menu_pos);
	break;
      case MUSIC_MENI:
	music_select(menu_pos);
	break;
      case PICTURE_MENI:
	picture_select(menu_pos);
	break;
      case SUB_MENI:
	sub_select(menu_pos);
	break;
      default:
	break;
     }
#ifdef _DEBUG_
   printf("meni 0> %d\n",menu_pos);
#endif   
   refresh_window();
}

void exit_press(void)
{
#ifdef _DEBUG_
   int i;
#endif

   switch (meni)
     {
      case MOVIE_MENI:
	menu_pos = 0;
	meni = ROOT_MENI;
	umountdrive(CDROM);
	break;
      case PLAY_MOVIE:
	xine_movie_press(LIRC_STOP);
	meni = MOVIE_MENI;
	n_files = 0;
	seek_dir(cur_path, MOVIE_TYPE, file_list, &n_files);
#ifdef _DEBUG_
	for (i=0;i<n_files;i++)
	  printf("%s %s\n",cur_path,file_list[i].pathfile);
#endif
	refresh_window();
	break;
      case PLAY_MUSIC:
	play_next = 0;
	xine_movie_press(LIRC_STOP);
	meni = MUSIC_MENI;
	break;
      case MUSIC_MENI:
	menu_pos = 0;
	meni = ROOT_MENI;
	umountdrive(CDROM);
	break;
      case PICTURE_MENI:
	menu_pos = 0;
	meni = ROOT_MENI;
	umountdrive(CDROM);
	break;
      case SHOW_PICTURE:
	meni = PICTURE_MENI;
	break;
      case SUB_MENI:
	meni = MOVIE_MENI;
	movie_init();
	break;
      default:
	break;
     }
   
   refresh_window();
}

gboolean on_lirc_event(GtkWidget *widget,
		       GdkEventKey *event,
		       gpointer user_data)
{
   return 0;
}

int next_song()
{
   if (meni == PLAY_MUSIC)
     {
	exit_press();
	down_press();
	select_press();
     }
   else if (meni == SHOW_PICTURE)
     {
	menu_pos++;
	refresh_window();
     }
   
   return 0;
}

int prev_song()
{
   if (meni == PLAY_MUSIC)
     {
	exit_press();
	up_press();
	select_press();
     }
   else if (meni == SHOW_PICTURE)
     {
	menu_pos--;
	refresh_window();
     }
   
   return 0;
}

gboolean on_window_key_press_event(GtkWidget *widget,
				   GdkEventKey *event,
				   gpointer user_data)
{
#ifdef _DEBUG_
   printf("to stiskam...%d\n",event->keyval);
#endif
   
   // when in osd mode just pass everything to xine
   if (osd_mode)
     {
	switch (event->keyval)
	  {
	   case 48: //0
	       {
		  xine_movie_press(LIRC_0);
		  break;
	       }
	   case 49: //1
	       {
		  xine_movie_press(LIRC_1);
		  break;
	       }
	   case 50: //2
	       {
		  xine_movie_press(LIRC_2);
		  break;
	       }
	   case 51: //3
	       {
		  xine_movie_press(LIRC_3);
		  break;
	       }
	   case 52: //4
	       {
		  xine_movie_press(LIRC_4);
		  break;
	       }
	   case 53: //5
	       {
		  xine_movie_press(LIRC_5);
		  break;
	       }
	   case 54: //6
	       {
		  xine_movie_press(LIRC_6);
		  break;
	       }
	   case 55: //7
	       {
		  xine_movie_press(LIRC_7);
		  break;
	       }
	   case 56: //8
	       {
		  xine_movie_press(LIRC_8);
		  break;
	       }
	   case 57: //9
	       {
		  xine_movie_press(LIRC_9);
		  break;
	       }
	  }
     }
   
   switch (event->keyval)
     {
      case 65362:
	  {
	     // press up
	     up_press();
#ifdef _DEBUG_
	     printf("up..\n");
#endif
	     break;
	  }
      case 65364:
	  {
	     // press down
	     // press...65364
	     down_press();
#ifdef _DEBUG_
	     printf("down...\n");
#endif
	     break;
	  }
      case 65363:
	  {
	     // press right
	     // press...65363
	     right_press();
#ifdef _DEBUG_
	     printf("right...\n");
#endif
	     break;
	  }
      case 65361:
	  {
	     // press left
	     // press...65361
	     left_press();
#ifdef _DEBUG_
	     printf("left...\n");
#endif
	     break;
	  }
      case 65293:
	  {
	     // enter
	     // press...65293
#ifdef _DEBUG_
	     printf("Enter -> %d\n",menu_pos);
#endif
	     select_press();
	     break;
	  }
      case 65307:
	  {
	     // exit press esc
#ifdef _DEBUG_
	     printf("ESC -> %d\n",menu_pos);
#endif
	     exit_press();
	     break;
	  }
      case 110:
	  {
	     // press n
	     // upgrade mediabox software
	     char run_string[1024];
	     sprintf(run_string,"xterm -e %s/upgrade",DIRECTORY);
	     system(run_string);
	     break;
	  }
      case 113:
	  {
	     // press REW (q)
#ifdef _DEBUG_
	     printf("izvajam REW\n");
#endif
	     xine_movie_press(LIRC_REW);
	     break;
	  }
      case 112:
	  {
#ifdef _DEBUG_
	     printf("izvajam play\n");
#endif
	     xine_movie_press(LIRC_PLAY);
	     break;
	  }
      case 101:
	  {
	     // press FF (e)
#ifdef _DEBUG_
	printf("izvajam FF\n");
#endif
	     xine_movie_press(LIRC_FF);
	     break;
	  }
      case 97:
	  {
	     xine_movie_press(LIRC_SLOWMOTION);
	     break;
	  }
      case 100:
	  {
	     xine_movie_press(LIRC_FASTMOTION);
	     break;
	  }
      case 111:
	  {
	     xine_movie_press(LIRC_OSD);
	     break;
	  }
      case 119:
	  { // pan/scan up
	     xine_movie_press(LIRC_PAN_SCAN_UP);
	     break;
	  }
      case 115:
	  { // pan/scan down
	     xine_movie_press(LIRC_PAN_SCAN_DOWN);
	     break;
	  }
      case 114:
	  { // hue up - r
	     xine_movie_press(LIRC_HUE_UP);
	     break;
	  }
      case 102:
	  { // hue down - f
	     xine_movie_press(LIRC_HUE_DOWN);
	     break;
	  }
      case 116:
	  { // brightness up - t
	     xine_movie_press(LIRC_BRIGHTNESS_UP);
	     break;
	  }
      case 103:
	  { // brightness down - g
	     xine_movie_press(LIRC_BRIGHTNESS_DOWN);
	     break;
	  }
      case 117:
	  { // saturation up - u
	     xine_movie_press(LIRC_SATURATION_UP);
	     break;
	  }
      case 106:
	  { // saturation down - j
	     xine_movie_press(LIRC_SATURATION_DOWN);
	     break;
	  }
      case 122:
	  { // contrast up - z
	     xine_movie_press(LIRC_CONTRAST_UP);
	     break;
	  }
      case 104:
	  { // contrast down - h
	     xine_movie_press(LIRC_CONTRAST_DOWN);
	     break;
	  }
      case 32:
	  {
	     // press space
#ifdef _DEBUG_
	printf("play...\n");
#endif
	     play_press();
	     break;
	  }
      case 109:
	  {
	     // press M for dvd menu
	     menu_press();
	     break;
	  }
      case 99:
	  { // next song or next picture
	     next_song();
	     break;
	  }
      case 121:
	  { // previous song or previous picture
	     prev_song();
	     break;
	  }
      default:
	break;
     }
   
   return 0;
}

gint send_mediabox_press(gint signal)
{
#ifdef _DEBUG_
   printf("Dobil singnal...iz menija %d\n",meni);
#endif
   
   switch (signal)
     {
      case LIRC_DOWN:
	if ((meni == PLAY_MUSIC) || (meni == PLAY_MOVIE))
	  xine_movie_press(signal);
	else
	  down_press();
	break;
      case LIRC_UP:
	if ((meni == PLAY_MUSIC) || (meni == PLAY_MOVIE))
	  xine_movie_press(signal);
	else
	  up_press();
	break;
      case LIRC_PLAY:
      case LIRC_ENTER:
	if ((meni == PLAY_MUSIC) || (meni == PLAY_MOVIE))
	  xine_movie_press(signal);
	else
	  select_press();
	break;
      case LIRC_EXIT:
	  exit_press();
	break;
      case LIRC_NEXT:
	if (meni == PLAY_MUSIC)
	  next_song();
	break;
      case LIRC_PREV:
	if (meni == PLAY_MUSIC)
	  prev_song();
	break;
      case LIRC_PAUSE:
      case LIRC_0:
      case LIRC_1:
      case LIRC_2:
      case LIRC_3:
      case LIRC_4:
      case LIRC_5:
      case LIRC_6:
      case LIRC_7:
      case LIRC_8:
      case LIRC_9:
      case LIRC_FF:
      case LIRC_REW:
      case LIRC_OSD:
      case LIRC_STOP:
	if ((meni == PLAY_MUSIC) || (meni == PLAY_MOVIE))
	  xine_movie_press(signal);
	break;

      default:
	break;
     }
   return 0;
}

void key_init(void)
{
}
