/*
 * Copyright (C) 2003 Andrej Bagon <andrej.bagon@uni-mb.si>
 *
 * This file is part of media-box, a free multimedia system.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <glib.h>
#include <gtk/gtk.h>

#include "interface.h"
#include "keypress.h"
#include "lirc/lirc_client.h"

int lirc_enable;
uint lirc_timeout;

typedef struct {
  struct lirc_config   *config;
  int                   fd;
} _lirc_t;

_lirc_t lirc;


void lirc_loop( gpointer data,
		gint source, 
		GdkInputCondition condition )
{
   char *code, *c;
   int ret;

   ret = 0;
   lirc_nextcode(&code);
#ifdef _DEBUG_
   printf("Code...%s\n",code);
#endif
   if(code == NULL) 
     return;

   ret = lirc_code2char(lirc.config, code, &c);
   
   if (c == NULL)
     ret = lirc_code2char(lirc.config, code, &c);
   if (code)
     free(code);
   
#ifdef _DEBUG_
   printf("Command Received = '%s' -> ret: %d\n", c,ret);
#endif
   
   if (c == NULL)
     return;
   
   if (!strncmp(c,"up",2))
     {
	send_mediabox_press(LIRC_UP);
     }
   else if (!strncmp(c,"down",4))
     {
	send_mediabox_press(LIRC_DOWN);
     }
   else if (!strncmp(c,"ent",3))
     {
	send_mediabox_press(LIRC_ENTER);
     }
   else if (!strncmp(c,"exit",4))
     {
	send_mediabox_press(LIRC_EXIT);
     }
   else if (!strncmp(c,"play",4))
     {
	send_mediabox_press(LIRC_PLAY);
     }
   else if (!strncmp(c,"ff",2))
     {
	send_mediabox_press(LIRC_FF);
     }
   else if (!strncmp(c,"rew",3))
     {
	send_mediabox_press(LIRC_REW);
     }
   else if (!strncmp(c,"stop",4))
     {       
	send_mediabox_press(LIRC_STOP);
     }
   else if (!strncmp(c,"pause",5))
     {	
	send_mediabox_press(LIRC_PAUSE);
     }
   else if (!strncmp(c,"osd",3))
     {
	send_mediabox_press(LIRC_OSD);
     }
   else if (!strncmp(c,"1",1))
     {
	send_mediabox_press(LIRC_1);
     }
   else if (!strncmp(c,"2",1))
     {
	send_mediabox_press(LIRC_2);
     }
   else if (!strncmp(c,"3",1))
     {
	send_mediabox_press(LIRC_3);
     }
   else if (!strncmp(c,"4",1))
     {
	send_mediabox_press(LIRC_4);
     }
   else if (!strncmp(c,"5",1))
     {
	send_mediabox_press(LIRC_5);
     }
   else if (!strncmp(c,"6",1))
     {
	send_mediabox_press(LIRC_6);
     }
   else if (!strncmp(c,"7",1))
     {
	send_mediabox_press(LIRC_7);
     }
   else if (!strncmp(c,"8",1))
     {
	send_mediabox_press(LIRC_8);
     }
   else if (!strncmp(c,"9",1))
     {
	send_mediabox_press(LIRC_9);
     }
   else if (!strncmp(c,"0",1))
     {
	send_mediabox_press(LIRC_0);
     }
   else if (!strncmp(c,"next",4))
     {
	send_mediabox_press(LIRC_NEXT);
     }
   else if (!strncmp(c,"prev",4))
     {
	send_mediabox_press(LIRC_PREV);
     }
   
   
   
   
//	if(ret == -1) 
//	  break;

//   return 0;
}

void init_lirc(void)
{
   lirc_buffer_pos = 0;
   
   if((lirc.fd = lirc_init("mediabox", 1)) == -1)
     {
	lirc_enable = 0;
	return;
     }

   if(lirc_readconfig(NULL, &lirc.config, NULL) != 0)
     {
	lirc_enable = 0;
	return;
     }

		 
   gdk_input_add(lirc.fd, GDK_INPUT_READ, lirc_loop, NULL);
   lirc_enable = 1;

}

void deinit_lirc(void)
{
   if(lirc_enable)
     {
	lirc_freeconfig(lirc.config);
	lirc_deinit();
     }
}

