/*
 * Copyright (C) 2003 Andrej Bagon <andrej.bagon@uni-mb.si>
 *
 * This file is part of media-box, a free multimedia system.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 */

#ifndef HAVE_MEDIABOX_H
#define HAVE_MEDIABOX_H
#include <stdio.h>
#include <gtk/gtk.h>
#include <X11/X.h>
#include <X11/Xlib.h>

/* mediabox includes */
#include "interface.h"
#include "main_interface.h"
#include "movie_interface.h"
#include "music_interface.h"
#include "picture_interface.h"
#include "sub_interface.h"
#include "keypress.h"
#include "skin.h"
#include "xine.h"
#include "automount.h"
#include "filename.h"
#include "lirc.h"

int menu_pos;
int meni;
int prev_meni;
int osd_mode;

/* buffer for receiving lirc actions */
#define MAX_LIRC_COMMAND 10
int lirc_buffer[MAX_LIRC_COMMAND];
int lirc_buffer_pos;

/* list for media files and for subtitles */
struct files file_list[10000];

/* File types */
#define MOVIE_TYPE 1
#define SUB_TYPE 2
#define MUSIC_TYPE 3
#define PICTURE_TYPE 4
#define DIRECTORY_TYPE 5
#define CDDA_TYPE 6
#define PLAYLIST_FILE 7

char cur_path[PATH_MAX];
int n_files;
int play_next;

/* commands to control lirc */
#define LIRC_UP               1
#define LIRC_DOWN             2
#define LIRC_LEFT             3
#define LIRC_RIGHT            4
#define LIRC_ENTER            5
#define LIRC_EXIT             6
#define LIRC_PLAY             7
#define LIRC_PAUSE            8
#define LIRC_STOP             9
#define LIRC_NEXT            10
#define LIRC_PREV            11
#define LIRC_FF              12
#define LIRC_REW             13
#define LIRC_EJECT           14
#define LIRC_MENU1           15
#define LIRC_TIME            16  // obsolete
#define LIRC_FASTMOTION      17
#define LIRC_SLOWMOTION      18
#define LIRC_OSD             19
#define LIRC_0               20
#define LIRC_1               21
#define LIRC_2               22
#define LIRC_3               23
#define LIRC_4               24
#define LIRC_5               25
#define LIRC_6               26
#define LIRC_7               27
#define LIRC_8               28
#define LIRC_9               29
#define LIRC_PAN_SCAN_UP     30
#define LIRC_PAN_SCAN_DOWN   31
#define LIRC_HUE_UP          32
#define LIRC_HUE_DOWN        33
#define LIRC_BRIGHTNESS_UP   34
#define LIRC_BRIGHTNESS_DOWN 35
#define LIRC_SATURATION_UP   36
#define LIRC_SATURATION_DOWN 37
#define LIRC_CONTRAST_UP     38
#define LIRC_CONTRAST_DOWN   39

/* meni position */
#define ROOT_MENI 0
#define MOVIE_MENI 1
#define MUSIC_MENI 2
#define PICTURE_MENI 3
#define PLAY_MOVIE 4
#define PLAY_MUSIC 5
#define SHOW_PICTURE 6
#define SUB_MENI 7


/* Images */
GdkPixbuf *images[50];

GtkWidget *picture_window;
GtkWidget *picture_da;
                
/* main window */
GtkWidget *window;

Display *my_display;
int my_screen;

/* Background image and info */
GdkPixbuf *background;
int back_width, back_height;

#define CDROM "/cdrom"
#define CDROM_DEVICE "/dev/cdrom"
#define DVD_DEVICE "/dev/dvd"

#endif // HAVE_MEDIABOX_H
