/*
 * Copyright (C) 2003 Andrej Bagon <andrej.bagon@uni-mb.si>
 *
 * This file is part of media-box, a free multimedia system.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 */

#include <stdlib.h>
#include <stdio.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <glib.h>
#include <sys/types.h>

#include "media-box.h"
#include "filename.h"
#include "xine.h"

// maximum movie files listed in divx file browser
#define MAX_DISPLAY_DIVX 12

void music_select(gint select)
{
#ifdef _DEBUG_
   printf("music select: %d -> %d\n",select,file_list[menu_pos].type);
#endif
   if (file_list[menu_pos].type == DIRECTORY_TYPE)
     {
	sprintf(cur_path,"%s",file_list[menu_pos].pathfile);
	n_files = 0;
	menu_pos = 0;
	seek_dir(cur_path, MUSIC_TYPE, file_list, &n_files);
	
	music_meni ( &menu_pos );
     }
   else if (file_list[menu_pos].type == PLAYLIST_FILE)
     {
	sprintf(cur_path,"%s",file_list[menu_pos].pathfile);
	n_files = menu_pos;
	menu_pos = 0;
	seek_dir(cur_path, PLAYLIST_FILE, file_list, &n_files);
	
	music_meni ( &menu_pos );
     }
   else
     {
	meni = PLAY_MUSIC;
	prev_meni = MUSIC_MENI;
	play_next = 1;
	play_xine(file_list[menu_pos].pathfile,NULL);
     }
}

void music_text(gint *select)
{
   gint i,j,k;
   PangoLayout *layout;
   char colored_text[2048]; // this is bad...
   
   /* max files in the list*/
   i = MAX_DISPLAY_DIVX * (*select/MAX_DISPLAY_DIVX);
   j = i + MAX_DISPLAY_DIVX;
   
   if (j >= n_files)
     j = n_files;
   
   k = 0;
   layout = gtk_widget_create_pango_layout(da, NULL);
   
   for (;i<j;i++)
     {
	sprintf(colored_text,"<span font_desc=\"%s\" foreground=\"#%s\">%s</span>", font_info.name, font_info.color, file_list[i].filename);
	fix_text(colored_text);
	pango_layout_set_width(layout, 660000);
	pango_layout_set_wrap (layout, PANGO_WRAP_CHAR);
	pango_layout_set_spacing(layout,6500000);
	pango_layout_set_markup(layout, colored_text, -1);
	gtk_paint_layout(da->style, da->window,
			 GTK_STATE_NORMAL, 1, NULL, da,
			 NULL,mp3_info.browser_x, mp3_info.browser_y+(k*30),
			 layout);
	k++;
     }
   
   free(layout);
}

void mp3_info_text(int x, int y, char *text_info)
{
  PangoLayout *layout;
  char colored_text[2048]; // this is bad...
   
   sprintf(colored_text,"<span font_desc=\"%s\" foreground=\"#%s\">%s</span>",
	   font_info.name, font_info.color, text_info);
   fix_text(colored_text);
   layout = gtk_widget_create_pango_layout(da, NULL);

   pango_layout_set_width(layout, 660000);
   pango_layout_set_wrap (layout, PANGO_WRAP_CHAR);
   pango_layout_set_spacing(layout,6500000);
   pango_layout_set_markup(layout, colored_text, -1);
   gtk_paint_layout(da->style, da->window,
		    GTK_STATE_NORMAL, 1, NULL, da,
		    NULL, x, y,
		    layout);
   free(layout);
}

void play_music_refresh(void)
{
   gdk_pixbuf_copy_area (background, 0, 0, back_width, back_height,
			 frame, 0, 0);
   
   /* music title */
   put_picture(mp3_info.title_x, mp3_info.title_y, 18, 255);
   
   /* background of files */
   put_picture(20,130,37,60);
   
   gtk_widget_queue_draw (da);

}

void music_meni (gint *mus_select)
{

   if (*mus_select < 0)
     *mus_select = 0; 
   if (*mus_select >= (n_files - 1))
     *mus_select = n_files - 1;
   
   gdk_pixbuf_copy_area (background, 0, 0, back_width, back_height,
			 frame, 0, 0);
   
   /* music title */
   put_picture(mp3_info.title_x, mp3_info.title_y, 18, 255);

   /* background of files */
   put_picture(20,130,37,60);
   
   /* put file indicator*/
   if (play_next != 1)
     put_picture(mp3_info.browser_x-20, mp3_info.browser_y+(30 * (*mus_select % MAX_DISPLAY_DIVX)), 10, 100);
      
   gtk_widget_queue_draw (da);
   
   if (play_next == 1)
     {
#ifdef _DEBUG_
	printf("select: %d of %d\n",*mus_select,n_files);
#endif
	if (*mus_select != (n_files-1))
	  {
	     *mus_select = *mus_select + 1;
#ifdef _DEBUG_
	     printf("playing: %d\n",*mus_select);
#endif
	     music_select(*mus_select);
	  }
	else
	  play_next = 0;
     }
}

void music_init(int type)
{
   menu_pos = 0;
   n_files = 0;
   sprintf(cur_path,"%s",CDROM);
   if (type == 0)
     {
	seek_dir(cur_path, MUSIC_TYPE, file_list, &n_files);
	play_next = 0;
     }
   else
     {
	seek_audio(CDROM_DEVICE, file_list, &n_files);
	play_next = 1;
     }
   
   music_meni ( &menu_pos );
}
