/*
 * Copyright (C) 2003 Andrej Bagon <andrej.bagon@uni-mb.si>
 *
 * This file is part of media-box, a free multimedia system.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 */

#include <stdlib.h>
#include <stdio.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <glib.h>
#include <sys/types.h>

#include "media-box.h"

// maximum movie files listed in divx file browser
#define MAX_DISPLAY_DIVX 12

void picture_select(gint select)
{
   if (file_list[menu_pos].type == DIRECTORY_TYPE)
     {
	sprintf(cur_path,"%s",file_list[menu_pos].pathfile);
	n_files = 0;
	menu_pos = 0;
	seek_dir(cur_path, PICTURE_TYPE, file_list, &n_files);
	
	picture_meni ( &menu_pos );
     }
   else
     {
	GError *error;
	meni = SHOW_PICTURE;
	display_fullscreen_image(file_list[menu_pos].pathfile, &error);
     }
}

void picture_text(gint *select)
{
  gint i,j,k;
  PangoLayout *layout;
  char colored_text[200]; // this is bad...
   
  /* max files in the list*/
  i = MAX_DISPLAY_DIVX * (*select/MAX_DISPLAY_DIVX);
  j = i + MAX_DISPLAY_DIVX;
  
  if (j >= n_files)
     j = n_files;

  k = 0;
  for (;i<j;i++)
    {
       sprintf(colored_text,"<span font_desc=\"%s\" foreground=\"#%s\">%s</span>", font_info.name, font_info.color, file_list[i].filename);
       fix_text(colored_text);
       layout = gtk_widget_create_pango_layout(da, NULL);
       pango_layout_set_width(layout, 660000);
       pango_layout_set_wrap (layout, PANGO_WRAP_CHAR);
       pango_layout_set_spacing(layout,6500000);
       pango_layout_set_markup(layout, colored_text, -1);
       gtk_paint_layout(da->style, da->window,
			GTK_STATE_NORMAL, 1, NULL, da,
			NULL,image_info.browser_x,image_info.browser_y+(k*30),
			layout);
       k++;
    }
}

void picture_meni (gint *select)
{
   if (*select < 0)
     *select = 0;
   if (*select >= (n_files - 1))
     *select = n_files - 1;
   
   if (meni == SHOW_PICTURE)
     {
	GError *error;
	display_fullscreen_image(file_list[*select].pathfile, &error);
     }
   else
     {
	if (*select < 0)
	  *select = 0; 
	if (*select >= (n_files - 1))
	  *select = n_files - 1;
	
	gdk_pixbuf_copy_area (background, 0, 0, back_width, back_height,
			      frame, 0, 0);
	
	/* image title */
	put_picture(image_info.title_x, image_info.title_y, 19, 255);
	
	put_picture(20,130,37,60);
	
	/* put background on the selected movie */
	put_picture(image_info.browser_x-20, image_info.browser_y+(30 * (*select % MAX_DISPLAY_DIVX)), 10, 100);
	
	gtk_widget_queue_draw (da);
     }
}

void picture_init()
{
   menu_pos = 0;
   n_files = 0;
   sprintf(cur_path,"%s",CDROM);
   seek_dir(cur_path, PICTURE_TYPE, file_list, &n_files);
   picture_meni ( &menu_pos );
}

int display_fullscreen_image(const gchar *filename, GError **error)
{
   GdkPixbuf *picture_slika;
   gfloat value_x, value_y, t_value;
   
   //  picture_frame
   gdk_pixbuf_fill(frame, 0x00000000);
   printf("%s\n",filename);
   picture_slika = gdk_pixbuf_new_from_file (filename, NULL);
   if (picture_slika == NULL)
     {
	//          something went wront.. cant load
	printf("Something is wrong with file %s\n",file_list[n_files].pathfile);
	return -1;
     }
   
   value_x = gdk_pixbuf_get_width (picture_slika);
   value_y = gdk_pixbuf_get_height (picture_slika);
   t_value = 1;
   
   if ((value_x > 800) || (value_y > 600))
     {
	value_x = (float) 800/gdk_pixbuf_get_width (picture_slika);
	value_y = (float) 600/gdk_pixbuf_get_height (picture_slika);
	
	if (value_x > value_y)
	  t_value = value_y;
	else
	  t_value = value_x;
	
	value_x = gdk_pixbuf_get_width (picture_slika) * t_value;
	value_y = gdk_pixbuf_get_height (picture_slika) * t_value;
     }
   
   gdk_pixbuf_composite(picture_slika, frame,
			(int)((800 - value_x) / 2),
			(int)((600 - value_y) / 2),
			value_x,
			value_y,
			(int)((800 - value_x) / 2),
			(int)((600 - value_y) / 2),
			t_value,
			t_value,
			GDK_INTERP_BILINEAR,
			255);
   
   gtk_widget_queue_draw (da);
   g_object_unref(picture_slika);
   
   return 0;
}
