/*
 * Copyright (C) 2003 Andrej Bagon <andrej.bagon@uni-mb.si>
 *
 * This file is part of media-box, a free multimedia system.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include "skin.h"

#define LENGTH 100

int read_line(FILE *in, char *line)
{
   char znak;
   int i;
   int pass;
   
   i = 0;
   pass = 0;
   do
     {
	znak = fgetc(in);
	if (znak == '#')
	  pass = 1;
	
	if (pass == 0)
	  {
	     if (feof(in))
	       {
		  line[i] = '\0';
		  break;
	       }
	     
	     if (znak == '\r')
	       {
		  znak = fgetc(in);
		  if (znak == '\n')
		    znak = '\0';
	       }
	     line[i] = znak;
	     i++;
	  }
	else
	  { // read trought the whole line and ignore...
	     if (znak == '\r')
	       {
		  znak = fgetc(in);
		  if (znak == '\n')
		    znak = '\0';
	       }
	  }
	
     }
   while (znak != '\0');
   
   return 0;
}

int get_skin_info(FILE *in, struct skin *info)
{
   char f_line[LENGTH];
   
   // read in skin version number
   read_line(in, f_line);
   sprintf(info->version,"%s",f_line);
   
   // read in skin name
   read_line(in, f_line);
   sprintf(info->name,"%s",f_line);
   
   // read in the author
   read_line(in, f_line);
   sprintf(info->author,"%s",f_line);
   
   return 0;
}

int get_mainwindow_info(FILE *in, struct mainwindow *info)
{
   char f_line[LENGTH];
   
   read_line(in, f_line);
   sprintf(info->back_image,"%s",f_line);
   
   read_line(in, f_line);
   sprintf(info->main_image,"%s",f_line);
   
   read_line(in, f_line);
   info->main_x=atoi(f_line);
   
   read_line(in, f_line);
   info->main_y=atoi(f_line);
   
   read_line(in, f_line);
   sprintf(info->title_image,"%s",f_line);
   
   read_line(in, f_line);
   info->title_x=atoi(f_line);
   
   read_line(in, f_line);
   info->title_y=atoi(f_line);
   
   read_line(in, f_line);
   info->buttons=atoi(f_line);
   
   return 0;
}

int get_fonts_info(FILE *in, struct fonts *info)
{
   char f_line[LENGTH];
   
   read_line(in, f_line);
   sprintf(info->name,"%s",f_line);
   
   read_line(in, f_line);
   sprintf(info->color,"%s",f_line);
   
   return 0;
}

int get_divx_info(FILE *in, struct divx *info)
{
   char f_line[LENGTH];
   
   read_line(in, f_line);
   info->title_x=atoi(f_line);
   
   read_line(in, f_line);
   info->title_y=atoi(f_line);
   
   read_line(in, f_line);
   sprintf(info->title,"%s",f_line);
   
   read_line(in, f_line);
   info->browser_x=atoi(f_line);
   
   read_line(in, f_line);
   info->browser_y=atoi(f_line);
   
   read_line(in, f_line);
   sprintf(info->over,"%s",f_line);
   
   return 0;
}

int get_mp3_info(FILE *in, struct mp3 *info)
{
   char f_line[LENGTH];
   
   read_line(in, f_line);
   info->title_x=atoi(f_line);
   
   read_line(in, f_line);
   info->title_y=atoi(f_line);
   
   read_line(in, f_line);
   sprintf(info->title,"%s",f_line);
   
   read_line(in, f_line);
   info->browser_x=atoi(f_line);
   
   read_line(in, f_line);
   info->browser_y=atoi(f_line);
   
   read_line(in, f_line);
   sprintf(info->over,"%s",f_line);
   
   return 0;
}


int get_image_info(FILE *in, struct image *info)
{
   char f_line[LENGTH];
   
   read_line(in, f_line);
   info->title_x=atoi(f_line);
   
   read_line(in, f_line);
   info->title_y=atoi(f_line);
   
   read_line(in, f_line);
   sprintf(info->title,"%s",f_line);
   
   read_line(in, f_line);
   info->browser_x=atoi(f_line);

   read_line(in, f_line);
   info->browser_y=atoi(f_line);
   
   read_line(in, f_line);
   sprintf(info->over,"%s",f_line);
   
   return 0;
}

int get_button(FILE *in, struct button *but, int n)
{
   char f_line[LENGTH];
   
   read_line(in, f_line);
   but[n].x=atoi(f_line);
   
   read_line(in, f_line);
   but[n].y=atoi(f_line);
   
   read_line(in, f_line);
   sprintf(but[n].base,"%s",f_line);
   
   read_line(in, f_line);
   sprintf(but[n].over,"%s",f_line);

   fgets(f_line, 80, in);
   read_line(in, f_line);
   sprintf(but[n].down,"%s",f_line);

   read_line(in, f_line);
   sprintf(but[n].disabled,"%s",f_line);
   
   return 0;
}

int read_skin_config(void)
{
   FILE *in;
   char path[LENGTH];
   char f_line[LENGTH];
   int n;
   
   n = 0;
   sprintf(path,"%s/skin.ini",DIRECTORY);
   in=fopen(path,"r");
   if (in==NULL)
     {
	printf("error opening file...\n");
	return -1;
     }
   
   while (!feof(in))
     {
	read_line(in, f_line);
	if (!strncmp(f_line,"mediabox",8))
	  { // main info about skin
	     get_skin_info(in, &skin_info);
	  }
	
	if (!strncmp(f_line,"mainwindow",10))
	  { // we have main options
	     get_mainwindow_info(in, &main_info);
	  }
	
	if (!strncmp(f_line,"fontdescription",15))
	  { // we have font info
	     get_fonts_info(in, &font_info);
	  }
	
	if (!strncmp(f_line,"divxmenu",8))
	  {
	     get_divx_info(in, &divx_info);
	  }
   
	if (!strncmp(f_line,"mp3menu",8))
	  {
	     get_mp3_info(in, &mp3_info);
	  }
	
	if (!strncmp(f_line,"imagemenu",8))
	  {
	     get_image_info(in, &image_info);
	  }
	
	if (!strncmp(f_line,"button",6))
	  { // we have a button
	     get_button(in,buttons,n);
	     n++;
	  }
     }
   
   fclose(in);
   
   return 0;
}
