/*
 * Copyright (C) 2003 Andrej Bagon <andrej.bagon@uni-mb.si>
 *
 * This file is part of media-box, a free multimedia system.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 */


#include <stdio.h>
#include <string.h>
#include <math.h>

#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/keysym.h>
#include <X11/Xatom.h>
#include <X11/Xutil.h>

#include <xine.h>
#include <xine/xineutils.h>

#include "media-box.h"

#include <gtk/gtk.h>
#include <gdk/gdkx.h>

xine_t *xine;
xine_stream_t *stream;
xine_stream_t *spu_stream;
xine_video_port_t *vo_port;
xine_audio_port_t *ao_port;
xine_event_queue_t *event_queue;
xine_osd_t *osd;

static Display *display;
int screen;
static Window x_window;
int xpos, ypos, width, height, fullscreen;
double pixel_aspect;

int pos_stream, pos_time, length_time;
char mrl_file[4092];
int running = 0;
int time_out = 0;
int play_state = 0;
char configfile[2048];
int pan_scan = 0;
int osd_time[9];
int display_info;

void dest_size_cb(void *data, int video_width, int video_height, double video_pixel_aspect,
			 int *dest_width, int *dest_height, double *dest_pixel_aspect)  {

  if(!running)
    return;
  
  *dest_width        = width;
  *dest_height       = height;
  *dest_pixel_aspect = pixel_aspect;
}

void frame_output_cb(void *data, int video_width, int video_height,
		     double video_pixel_aspect, int *dest_x, int *dest_y,
		     int *dest_width, int *dest_height, 
		     double *dest_pixel_aspect, int *win_x, int *win_y)
{
   if(!running)
     return;
   
#ifdef _DEBUG_
//   printf("settings for video...%dx%d; %dx%d\n",xpos,ypos,width,height);
#endif
   *dest_x            = xpos; // 0
   *dest_y            = ypos; // 0
   *win_x             = xpos;
   *win_y             = ypos;
   *dest_width        = width;
   *dest_height       = height;
   *dest_pixel_aspect = pixel_aspect;
}

void event_listener(void *user_data, const xine_event_t *event)
{
   switch(event->type)
     { 
      case XINE_EVENT_UI_PLAYBACK_FINISHED:
	  {
	     running = 0;
#ifdef _DEBUG_
	     printf("runinng is off...\n");
#endif
	     break;
	  }
      case XINE_EVENT_PROGRESS:
	  {
#ifdef _DEBUG_
	     xine_progress_data_t *pevent = (xine_progress_data_t *) event->data;
	     printf("%s [%d%%]\n", pevent->description, pevent->percent);
#endif
	     break;
	  }
     }
}

int fix_mrl(char *input)
{
   int i,j,len;
   
   len = strlen(input);
#ifdef _DEBUG_
   printf("len: %d\n",len);
#endif
   for (i = 0; i < len; i++)
     {
	if (input[i] == '#')
	  {
#ifdef _DEBUG_
	     printf("nasel hash\n");
#endif
	     input[i] = '%';
	     for (j = len+2; j > i; j--)
	       {
		  input[j] = input[j-2];
	       }
	     input[i+1]='2';
	     input[i+2]='3';
	  }
     }
#ifdef _DEBUG_
   printf("|%s|\n",input);
#endif
   return 0;
}

gint get_music_info()
{
   char my_text[4092];
   
   sprintf(my_text,"File: %s",mrl_file);
   mp3_info_text(100,150,my_text);
   sprintf(my_text,"Title: %s", xine_get_meta_info(stream, XINE_META_INFO_TITLE));
   mp3_info_text(100,200,my_text);
   sprintf(my_text,"Artist: %s", xine_get_meta_info(stream, XINE_META_INFO_ARTIST));
   mp3_info_text(100,250,my_text);
   sprintf(my_text,"Sample rate: %d", xine_get_stream_info(stream, XINE_STREAM_INFO_AUDIO_SAMPLERATE));
   mp3_info_text(100,300,my_text);
   
   return 0;
}

int play_xine(char *mrl, char *sub) 
{
   x11_visual_t vis;
   double res_h, res_v;
   char *vo_driver = "xv";
   char *ao_driver = "alsa";
   int j;
      
   if (mrl)
     fix_mrl(mrl);
   if (sub)
     fix_mrl(sub);
   
   strncpy(mrl_file, mrl, strlen(mrl));
   
#ifdef _DEBUG_
   printf("mrl: '%s' sub: '%s'\n", mrl, sub);
#endif
   
   if(!XInitThreads())
     {
#ifdef _DEBUG_
	printf("XInitThreads() failed\n");
#endif
	meni = prev_meni;
	refresh_window();
	return 1;
     }
   
   xine = xine_new();
   sprintf(configfile, "%s%s", xine_get_homedir(), "/.mediabox_config");
   xine_config_load(xine, configfile);
   xine_init(xine);
   
   display = XOpenDisplay(NULL);
   screen  = XDefaultScreen(display);
   xpos    = 0;
   ypos    = 0;
   width   = DisplayWidth(display, screen);
   height  = DisplayHeight(display, screen);
   
   fullscreen = 0;
   osd_mode = 0;
   display_info = 0;
   osd_time[0]=osd_time[1]=osd_time[2]=osd_time[3]=0;
   osd_time[4]=osd_time[5]=osd_time[6]=osd_time[7]=osd_time[8]=0;
 
   x_window = GDK_WINDOW_XWINDOW(GTK_WIDGET (da)->window);

   res_h = (width * 1000 / DisplayWidthMM(display, screen));
   res_v = (height * 1000 / DisplayHeightMM(display, screen));
   
   vis.display           = display;
   vis.screen            = screen;
   vis.d                 = x_window;
   vis.dest_size_cb      = dest_size_cb;
   vis.frame_output_cb   = frame_output_cb;
   vis.user_data         = NULL;
   pixel_aspect          = res_v / res_h;

   if(fabs(pixel_aspect - 1.0) < 0.01)
     pixel_aspect = 1.0;
   
   vo_port = xine_open_video_driver(xine, vo_driver, XINE_VISUAL_TYPE_X11, (void *) &vis);
   
   ao_port = xine_open_audio_driver(xine , ao_driver, NULL);
   
   stream = xine_stream_new(xine, ao_port, vo_port);
   spu_stream = xine_stream_new(xine, NULL, vo_port);
   
   event_queue = xine_event_new_queue(stream);
   xine_event_create_listener_thread(event_queue, event_listener, NULL);
      
   xine_gui_send_vo_data(stream, XINE_GUI_SEND_DRAWABLE_CHANGED, (void *) x_window);
   xine_gui_send_vo_data(stream, XINE_GUI_SEND_VIDEOWIN_VISIBLE, (void *) 1);
   
   if(!xine_open(stream, mrl))
     {
#ifdef _DEBUG_
	printf("Unable to open mrl '%s'\n", mrl);
#endif
	return 1;
     }
   
   if (sub)
     {
	if (xine_open(spu_stream, sub))
	  {	     
	     xine_stream_master_slave(stream, spu_stream, 
				      XINE_MASTER_SLAVE_PLAY | XINE_MASTER_SLAVE_STOP);
	     xine_set_param(stream, XINE_PARAM_SPU_CHANNEL, 1);
	  }
     }
   
   if (!xine_play(stream, 0, 0))
     {	
#ifdef _DEBUG_
	printf("error playing...\n");
#endif
	return -1;
     }
   
   running = 1;
   j = xine_get_param(stream, XINE_PARAM_AUDIO_VOLUME);
#ifdef _DEBUG_
   printf("audio_volume: %d\n",j);
#endif

   
   time_out = gtk_timeout_add(1000,
			      gtk_xine_get_status,
			      NULL);
   return 0;
}

int exit_xine(void)
{
   xine_close(spu_stream);
   xine_close(stream);
   xine_event_dispose_queue(event_queue);
   xine_dispose(stream);
   xine_close_audio_driver(xine, ao_port);  
   xine_close_video_driver(xine, vo_port);
   xine_config_save(xine, configfile);
   xine_exit(xine);
   
   XCloseDisplay(display);
   
   // delete timeout
   gtk_timeout_remove(time_out);
   meni = prev_meni;
   refresh_window();
   
   return 0;
}

int init_xine()
{
   
   return 0;
}

gint gtk_xine_get_status()
{
   int p;
   char my_time[13];
   char my_text[4092];

   p = xine_get_status (stream);
   if (meni == PLAY_MUSIC)
     {
	if (display_info == 0)
	  {
	     display_info = 1;
//	     refresh_window();
	     get_music_info();
	  }
	else
	  {
	     GdkRegion*  region;
	     GdkRectangle rect;
	     
	     rect.x=0;
	     rect.width=800;
	     rect.y=350;
	     rect.height=150;
	     region=gdk_region_rectangle(&rect);
	     gdk_window_invalidate_region(GTK_WIDGET (da)->window,region,0);
	     gdk_window_process_updates(GTK_WIDGET (da)->window,0);
	     free(region);
	     
	     xine_get_pos_length (stream, &pos_stream, &pos_time, &length_time);
	     sprintf(my_text,"Bitrate: %d", xine_get_stream_info(stream, XINE_STREAM_INFO_AUDIO_BITRATE)/1000);
	     mp3_info_text(100,350,my_text);
	     convert_time(pos_time,my_time);
	     sprintf(my_text,"Time: %s", my_time);
	     mp3_info_text(100,400,my_text);
	     convert_time(length_time,my_time);
	     sprintf(my_text,"Total time: %s", my_time);
	     mp3_info_text(100,450,my_text);
	  }	
     }
   if (running == 0)
     {
	exit_xine();
	return 0;
     }
   
   return 1;
}

gint xine_set_play_speed(gint *speed, gint i )
{
   if (i == 0)
     *speed=*speed+1;
   else
     *speed=*speed-1;
   
   if (*speed == 1)
     xine_set_param(stream, XINE_PARAM_SPEED, XINE_SPEED_FAST_2);
   else if (*speed == 2)
     xine_set_param(stream, XINE_PARAM_SPEED, XINE_SPEED_FAST_4);
   else if (*speed > 2)
     *speed = 2;
   else if (*speed == 0)
     xine_set_param(stream, XINE_PARAM_SPEED, XINE_SPEED_NORMAL);
   else if (*speed == -1)
     xine_set_param(stream, XINE_PARAM_SPEED, XINE_SPEED_SLOW_2);
   else if (*speed == -2)
     xine_set_param(stream, XINE_PARAM_SPEED, XINE_SPEED_SLOW_4);
   else if (*speed < -2)
     *speed=-2;
   
   return 0;
}

gint xine_get_video_mode(int param)
{
   return (xine_get_param(stream, param));
}

gint xine_set_video_mode(int param, int value)
{
   xine_set_param(stream, param, value);
   
   return 0;
}

gint convert_time(int t, char *my_time)
{
   int h, m, s;
   int tt;
   
   tt = t / 1000;
   
   
   h = tt / (60*60);
   sprintf(my_time,"%02d",h);
   
   m = (tt / 60) % 60;
   sprintf(my_time,"%s:%02d", my_time, m);
   
   s = tt % 60;
   sprintf(my_time,"%s:%02d", my_time, s);
   
   return 0;
}

int time_add(int *t,int num)
{
   int i;
   char tt[12];

   xine_osd_hide(osd, 0);
   
   for (i=1;i<9;i++)
     {
	t[i-1]=t[i];
	tt[i-1]=t[i];
     }
   t[8] = num;
   
   sprintf(tt,"%d%d:%d%d:%d%d.%d%d%d",t[0],t[1],t[2],t[3],t[4],t[5],t[6],t[7],t[8]);
   
   xine_osd_draw_text(osd, 0, 0, tt, XINE_OSD_TEXT1);
   xine_osd_set_position(osd, 20, 10);
   xine_osd_show(osd, 0);
   
   return 0;
}

gint xine_movie_press(gint signal)
{
   xine_event_t event;
   
   if (meni != PLAY_MOVIE)
     {
	return 0;
     }
   
   switch (signal)
     {
      case LIRC_HUE_UP:
	  {
	     int i;
#ifdef _DEBUG_
	     printf("hue up\n");
#endif
	     i = xine_get_video_mode(XINE_PARAM_VO_HUE);
	     i = i + 1024;
	     if (i > 65535)
	       i = 65536;
	     
	     xine_set_video_mode(XINE_PARAM_VO_HUE, i);
	     break;
	  }
      case LIRC_HUE_DOWN:
	  {
	     int i;
#ifdef _DEBUG_
	     printf("hue down\n");
#endif
	     i = xine_get_video_mode(XINE_PARAM_VO_HUE);
	     i = i - 1024;
	     if (i < 0)
	       i = 0;

	     xine_set_video_mode(XINE_PARAM_VO_HUE, i);
	     break;
	  }
      case LIRC_BRIGHTNESS_UP:
	  {
	     int i;
#ifdef _DEBUG_
	     printf("brightness up\n");
#endif
	     i = xine_get_video_mode(XINE_PARAM_VO_BRIGHTNESS);
	     i = i + 1024;
	     if (i > 65535)
	       i = 65536;

	     xine_set_video_mode(XINE_PARAM_VO_BRIGHTNESS, i);
	     break;
	  }
      case LIRC_BRIGHTNESS_DOWN:
	  {
	     int i;
#ifdef _DEBUG_
	     printf("brightness down\n");
#endif
	     i = xine_get_video_mode(XINE_PARAM_VO_BRIGHTNESS);
	     i = i - 1024;
	     if (i < 0)
	       i = 0;

	     xine_set_video_mode(XINE_PARAM_VO_BRIGHTNESS, i);
	     break;
	  }
      case LIRC_CONTRAST_UP:
	  {
	     int i;
#ifdef _DEBUG_
	     printf("contrast up\n");
#endif
	     i = xine_get_video_mode(XINE_PARAM_VO_CONTRAST);
	     i = i + 1024;
	     if (i > 65535)
	       i = 65536;

	     xine_set_video_mode(XINE_PARAM_VO_CONTRAST, i);
	     break;
	  }
      case LIRC_CONTRAST_DOWN:
	  {
	     int i;
#ifdef _DEBUG_
	     printf("contrast down\n");
#endif
	     i = xine_get_video_mode(XINE_PARAM_VO_CONTRAST);
	     i = i - 1024;
	     if (i < 0)
	       i = 0;

	     xine_set_video_mode(XINE_PARAM_VO_CONTRAST, i);
	     break;
	  }
      case LIRC_SATURATION_UP:
	  {
	     int i;
#ifdef _DEBUG_
	     printf("saturation up\n");
#endif
	     i = xine_get_video_mode(XINE_PARAM_VO_SATURATION);
	     i = i + 1024;
	     if (i > 65535)
	       i = 65536;

	     xine_set_video_mode(XINE_PARAM_VO_SATURATION, i);
	     break;
	  }
      case LIRC_SATURATION_DOWN:
	  {
	     int i;
#ifdef _DEBUG_
	     printf("saturation down\n");
#endif
	     i = xine_get_video_mode(XINE_PARAM_VO_SATURATION);
	     i = i - 1024;
	     if (i < 0)
	       i = 0;

	     xine_set_video_mode(XINE_PARAM_VO_SATURATION, i);
	     break;
	  }
      case LIRC_PAN_SCAN_UP:
#ifdef _DEBUG_
	printf("pan/scan up\n");
#endif
	xpos = xpos - 3;
	ypos = ypos - 3;
	width = width + 6;
	height = height + 6;
	
	break;
      case LIRC_PAN_SCAN_DOWN:
#ifdef _DEBUG_
	printf("pan/scan down\n");
#endif
	xpos = xpos + 3;
	ypos = ypos + 3;
	width = width - 6;
	height = height - 6;

	break;
      case LIRC_FASTMOTION:
	xine_set_play_speed(&play_state,0);
	break;
      case LIRC_SLOWMOTION:
	xine_set_play_speed(&play_state,1);
	break;
      case LIRC_PAUSE:
      case LIRC_PLAY:
	if (play_state == 0)
	  {
	     xine_set_param (stream, XINE_PARAM_SPEED, XINE_SPEED_PAUSE);
	     play_state = -1;
	  }
	else
	  {
	     xine_set_param (stream, XINE_PARAM_SPEED, XINE_SPEED_NORMAL);
	     play_state = 0;
	  }
#ifdef _DEBUG_
	printf("play!!\n");
#endif
	break;
      case LIRC_STOP:
	exit_xine();
	break;
      case LIRC_UP:
#ifdef _DEBUG_
	printf("executing up...\n");
#endif
	event.type = 0;
	event.data = NULL;
	event.data_length = 0;
	event.type = XINE_EVENT_INPUT_UP;
	xine_event_send (stream, &event);
	break;
      case LIRC_DOWN:
#ifdef _DEBUG_
	printf("executing down...\n");
#endif
	event.type = 0;
	event.data = NULL;
	event.data_length = 0;
	event.type = XINE_EVENT_INPUT_DOWN;
	xine_event_send (stream, &event);
	break;
      case LIRC_LEFT:
#ifdef _DEBUG_
	printf("executing left...\n");
#endif
	event.type = 0;
	event.data = NULL;
	event.data_length = 0;
	event.type = XINE_EVENT_INPUT_LEFT;
	xine_event_send (stream, &event);
	break;
      case LIRC_RIGHT:
#ifdef _DEBUG_
	printf("executing right...\n");
#endif
	event.type = 0;
	event.data = NULL;
	event.data_length = 0;
	event.type = XINE_EVENT_INPUT_RIGHT;
	xine_event_send (stream, &event);
	break;
      case LIRC_ENTER:
#ifdef _DEBUG_
	printf("executing select...\n");
#endif
	if (osd_mode == 1)
	  {
	     // go to position
	     xine_play (stream, 0, osd_time[0]*36000000+osd_time[1]*3600000+
			osd_time[2]*600000+osd_time[3]*60000+
			osd_time[4]*10000+osd_time[5]*1000+
			osd_time[6]*100+osd_time[7]*10+osd_time[8]);
	     osd_mode = 0;
	     xine_osd_hide(osd, 0);
	     xine_osd_free(osd);
	  }
	else
	  {
	     event.type = 0;
	     event.data = NULL;
	     event.data_length = 0;
	     event.type = XINE_EVENT_INPUT_SELECT;
	     xine_event_send (stream, &event);
	  }
	break;
      case LIRC_MENU1:
#ifdef _DEBUG_
	printf("entering menu1...\n");
#endif
	event.type = 0;
	event.data = NULL;
	event.data_length = 0;
	event.type = XINE_EVENT_INPUT_MENU1;
	xine_event_send (stream, &event);
	break;
      case LIRC_REW:
	  {
	     int ret;
	     xine_get_pos_length (stream, &pos_stream, &pos_time, &length_time);
#ifdef _DEBUG_
	     printf("Time...: %d %d %d\n",pos_stream, pos_time, length_time);
#endif
	     ret = xine_play (stream, 0, pos_time - 60000);
	     xine_get_pos_length (stream, &pos_stream, &pos_time, &length_time);
#ifdef _DEBUG_
	     printf("Time...: %d %d %d - %d\n",pos_stream, pos_time, length_time,ret);
#endif
	     break;
	  }
      case LIRC_FF:
	  {
	     xine_get_pos_length (stream, &pos_stream, &pos_time, &length_time);
#ifdef _DEBUG_
	     printf("Time...: %d %d %d\n",pos_stream, pos_time, length_time);
#endif
	     xine_play (stream, 0, pos_time + 60000);
	     break;
	  }
      case LIRC_OSD:
	  {
	     if (osd_mode == 0)
	       {
		  char my_time[13];
		  int h,m,s,ms;
		  
		  osd_mode = 1;
		  osd = xine_osd_new(stream, 0, 0, width, height);
		  xine_osd_set_font(osd, "sans", 20 /*font*/ );
		  xine_osd_set_text_palette(osd, XINE_TEXTPALETTE_WHITE_BLACK_TRANSPARENT, 
					    XINE_OSD_TEXT1);
		  xine_get_pos_length (stream, &pos_stream, &pos_time, &length_time);

		  h=pos_time/3600000;
		  sprintf(my_time,"%02d",h);
		  if (h)
		    pos_time=pos_time-3600000*h;
		  
		  m=pos_time/60000;
		  sprintf(my_time,"%s:%02d",my_time,m);
		  if (m)
		    pos_time=pos_time-60000*m;
		  
		  s=pos_time/1000;
		  sprintf(my_time,"%s:%02d",my_time,s);
		  if (s)
		    pos_time=pos_time-1000*s;
		  
		  ms=pos_time;
		  sprintf(my_time,"%s.%02d",my_time,ms);

		  xine_osd_draw_text(osd, 0, 0, my_time, XINE_OSD_TEXT1);
		  xine_osd_set_position(osd, 20, 10);
		  xine_osd_show(osd, 0);
	       }
	     else
	       {
		  osd_mode = 0;
		  xine_osd_hide(osd, 0);
		  xine_osd_free(osd);
	       }
	     break;
	  }
      case LIRC_0:
	  {
	     if (osd_mode == 1)
	       {
		  time_add(osd_time, 0);
#ifdef _DEBUG_
		  printf("%d%d:%d%d:%d%d.%d%d%d\n",osd_time[0],osd_time[1],osd_time[2],osd_time[3],
			 osd_time[4],osd_time[5],osd_time[6],osd_time[7],osd_time[8]);
#endif
	       }
	     break;
	  }
      case LIRC_1:
	  {
	     if (osd_mode == 1)
	       {
		  time_add(osd_time, 1);
#ifdef _DEBUG_
		  printf("%d%d:%d%d:%d%d.%d%d%d\n",osd_time[0],osd_time[1],osd_time[2],osd_time[3],
			 osd_time[4],osd_time[5],osd_time[6],osd_time[7],osd_time[8]);
#endif
	       }
    	     break;
	  }
      case LIRC_2:
	  {
	     if (osd_mode == 1)
	       {
		  time_add(osd_time, 2);
#ifdef _DEBUG_
		  printf("%d%d:%d%d:%d%d.%d%d%d\n",osd_time[0],osd_time[1],osd_time[2],osd_time[3],
			 osd_time[4],osd_time[5],osd_time[6],osd_time[7],osd_time[8]);
#endif
	       }
	     break;
	  }
      case LIRC_3:
	  {
	     if (osd_mode == 1)
	       {
		  time_add(osd_time, 3);
#ifdef _DEBUG_
		  printf("%d%d:%d%d:%d%d.%d%d%d\n",osd_time[0],osd_time[1],osd_time[2],osd_time[3],
			 osd_time[4],osd_time[5],osd_time[6],osd_time[7],osd_time[8]);
#endif
	       }
	     break;
	  }
      case LIRC_4:
	  {
	     if (osd_mode == 1)
	       {
		  time_add(osd_time, 4);
#ifdef _DEBUG_
		  printf("%d%d:%d%d:%d%d.%d%d%d\n",osd_time[0],osd_time[1],osd_time[2],osd_time[3],
			 osd_time[4],osd_time[5],osd_time[6],osd_time[7],osd_time[8]);
#endif
	       }
	     break;
	  }
      case LIRC_5:
	  {
	     if (osd_mode == 1)
	       {
		  time_add(osd_time, 5);
#ifdef _DEBUG_
		  printf("%d%d:%d%d:%d%d.%d%d%d\n",osd_time[0],osd_time[1],osd_time[2],osd_time[3],
			 osd_time[4],osd_time[5],osd_time[6],osd_time[7],osd_time[8]);
#endif
	       }
	     break;
	  }
      case LIRC_6:
	  {
	     if (osd_mode == 1)
	       {
		  time_add(osd_time, 6);
#ifdef _DEBUG_
		  printf("%d%d:%d%d:%d%d.%d%d%d\n",osd_time[0],osd_time[1],osd_time[2],osd_time[3],
			 osd_time[4],osd_time[5],osd_time[6],osd_time[7],osd_time[8]);
#endif
	       }
	     break;
	  }
      case LIRC_7:
	  {
	     if (osd_mode == 1)
	       {
		  time_add(osd_time, 7);
#ifdef _DEBUG_
		  printf("%d%d:%d%d:%d%d.%d%d%d\n",osd_time[0],osd_time[1],osd_time[2],osd_time[3],
			 osd_time[4],osd_time[5],osd_time[6],osd_time[7],osd_time[8]);
#endif
	       }
	     break;
	  }
      case LIRC_8:
	  {
	     if (osd_mode == 1)
	       {
		  time_add(osd_time, 8);
#ifdef _DEBUG_
		  printf("%d%d:%d%d:%d%d.%d%d%d\n",osd_time[0],osd_time[1],osd_time[2],osd_time[3],
			 osd_time[4],osd_time[5],osd_time[6],osd_time[7],osd_time[8]);
#endif
	       }
	     break;
	  }
      case LIRC_9:
	  {  
	     if (osd_mode == 1)
	       {
		  time_add(osd_time, 9);
#ifdef _DEBUG_
		  printf("%d%d:%d%d:%d%d.%d%d%d\n",osd_time[0],osd_time[1],osd_time[2],osd_time[3],
			 osd_time[4],osd_time[5],osd_time[6],osd_time[7],osd_time[8]);
#endif
	       }
	     break;
	  }
      default:
	break;
     }
   
   return 0;
}
